@@ -248,6 +248,9 @@ for (gees, elty) in ((:dgees_, :Float64),
             ldvs = max(size(ws.vs, 1), 1)
             lwork = length(ws.work)
             if select isa Function
+                if Sys.ARCH == :aarch64
+                    throw(ArgumentError("gees: using a select function is not possible on aarch64 architecture"))
+                end
                 sfunc(wr, wi) = schurselect(select, wr, wi)
                 sel_func = @cfunction($(Expr(:$, :sfunc)), Cint,
                     (Ptr{Cdouble}, Ptr{Cdouble}))
@@ -311,13 +314,11 @@ It is possible to select the eigenvalues appearing in the top left corner of the
     - `id`: Interior of disk (abs(eigenvalue)^2 < criterium) 
     - `ed`: Exterior of disk (abs(eigenvalue)^2 >= criterium)
   and setting `criterium`.
-- by setting `select` equal to a function used to sort the eigenvalues during the decomponsition. In this case, the `criterium` keyword isn't used.
-The function should have the signature `f(wr::T, wi::T) -> Bool`, where
-`wr` and `wi` are the real and imaginary parts of the eigenvalue, and `T == eltype(A)`. 
+- by setting `select` equal to a function used to sort the eigenvalues during the decomponsition. In this case, the `criterium` keyword isn't used. The function should have the signature `f(wr::T, wi::T) -> Bool`, where `wr` and `wi` are the real and imaginary parts of the eigenvalue, and `T == eltype(A)`. This is not available on aarch64 architecture.
 
 Returns `A`, `vs` containing the Schur vectors, and `ws.eigen_values`.
 
-See also FastLapackInterface.SCHURODER
+See also FastLapackInterface.SCHURORDER
 """
 gees!(ws::SchurWs, jobvs::AbstractChar, A::AbstractMatrix; kwargs...)
 
@@ -461,6 +462,9 @@ for (gges, elty) in ((:dgges_, :Float64),
             ldvsl = size(ws.vsl, 1)
             ldvsr = size(ws.vsr, 1)
             if select isa Function
+                if Sys.ARCH == :aarch64
+                    throw(ArgumentError("gges: using a select function is not possible on aarch64 architecture"))
+                end
                 sfunc(αr, αi, β) = schurselect(select, αr, αi, β)
                 sel_func = @cfunction($(Expr(:$, :sfunc)), Cint,
                     (Ptr{Cdouble}, Ptr{Cdouble}, Ptr{Cdouble}))
@@ -531,16 +535,13 @@ It is possible to select the eigenvalues appearing in the top left corner of the
     - `id`: Interior of disk (abs(eigenvalue)^2 < criterium) 
     - `ed`: Exterior of disk (abs(eigenvalue)^2 >= criterium)
   and setting `criterium`.
-- by setting `select` equal to a function used to sort the eigenvalues during the decomposition. In this case, the `criterium` keyword isn't used.
-The function should have the signature `f(αr::T, αi::T, β::T) -> Bool` where `T == eltype(A)`. 
-An eigenvalue `(αr[j]+αi[j])/β[j]` is selected if `f(αr[j],αi[j],β[j])` is true, 
-i.e. if either one of a complex conjugate pair of eigenvalues is selected,
-then both complex eigenvalues are selected.
+- by setting `select` equal to a function used to sort the eigenvalues during the decomposition. In this case, the `criterium` keyword isn't used. The function should have the signature `f(αr::T, αi::T, β::T) -> Bool` where `T == eltype(A)`. An eigenvalue `(αr[j]+αi[j])/β[j]` is selected if `f(αr[j],αi[j],β[j])` is true, i.e. if either one of a complex conjugate pair of eigenvalues is selected, then both complex eigenvalues are selected. This is not available on aarch64 architecture.
+
 The generalized eigenvalues components are returned in `ws.α` and `ws.β` where `ws.α` is a complex vector and `ẁs.β`, a real vector.
 The generalized eigenvalues (`ws.α./ws.β`) are returned in `ws.eigen_values`, a complex vector. 
 The left Schur vectors are returned in `ws.vsl` and the right Schur vectors are returned in `ws.vsr`.
 
-See also FastLapackInterface.SCHURODER
+See also FastLapackInterface.SCHURORDER
 """
 gges!(
     ws::GeneralizedSchurWs, jobvsl::AbstractChar, jobvsr::AbstractChar, A::AbstractMatrix,
